pub fn scan_raw_padding(
bytes: &[u8],
target_byte: u8,
min_length: usize,
text_section_offset: u64,
) -> Vec<u64>Expand description
Scans a byte slice for consecutive runs of target_byte of length at least min_length.
Returns the absolute virtual memory addresses of all bytes within the matching runs.